@@ -25,9 +25,9 @@ drawIsoquants<-function(x,y=NULL,number=6,steps=NULL){
     spp.perc <- sort(x$spp, decreasing = TRUE)
     xaxlab <- names(spp.perc)
     op <- par(mar = c(3, 4, 4, 2))
+    on.exit(par(op))
     text(1:length(spp.perc)+adjX, spp.perc+adjY, labels = xaxlab, pos = 3, 
          cex=cex,srt=90)
     for (i in 1:length(spp.perc)) lines(c(i, i), c(spp.perc[i], 
                                                    0), col = "lightgray", lty = 2)
-    par(op)
 }
